@@ -1,9 +1,14 @@
 """Saving utilities for YAML, JSON etc."""
 import json
 from collections import OrderedDict
-from typing import Any, Dict
+from typing import Any
 
-from ruamel.yaml import YAML, RoundTripRepresenter, SafeRepresenter, add_representer
+from ruamel.yaml import (
+    YAML,
+    RoundTripRepresenter,
+    SafeRepresenter,
+    add_representer,
+)
 
 
 class UnPrettyRTRepresenter(RoundTripRepresenter):
@@ -27,9 +32,15 @@ class PrettySafeRepresenter(SafeRepresenter):
         return self.represent_scalar("tag:yaml.org,2002:null", "")
 
 
-UnPrettyRTRepresenter.add_representer(None, UnPrettyRTRepresenter.represent_none)
-UnPrettySafeRepresenter.add_representer(None, UnPrettySafeRepresenter.represent_none)
-PrettySafeRepresenter.add_representer(None, PrettySafeRepresenter.represent_none)
+UnPrettyRTRepresenter.add_representer(
+    None, UnPrettyRTRepresenter.represent_none
+)
+UnPrettySafeRepresenter.add_representer(
+    None, UnPrettySafeRepresenter.represent_none
+)
+PrettySafeRepresenter.add_representer(
+    None, PrettySafeRepresenter.represent_none
+)
 
 
 representers = {
@@ -38,8 +49,8 @@ representers = {
 }
 
 
-def save_str_to_file(string: str, path: str, encoding: str = "utf-8") -> None:
-    """Save string to file
+def save_text(string: str, path: str, encoding: str = "utf-8") -> None:
+    """Save text string to file
 
     Args:
         string (str): String to save
@@ -54,7 +65,7 @@ def save_str_to_file(string: str, path: str, encoding: str = "utf-8") -> None:
 
 
 def save_yaml(
-    dictionary: Dict,
+    object: Any,
     path: str,
     encoding: str = "utf-8",
     pretty: bool = False,
@@ -63,7 +74,7 @@ def save_yaml(
     """Save dictionary to YAML file preserving order if it is an OrderedDict
 
     Args:
-        dictionary (Dict): Python dictionary to save
+        object (Any): Python object to save
         path (str): Path to YAML file
         encoding (str): Encoding of file. Defaults to utf-8.
         pretty (bool): Whether to pretty print. Defaults to False.
@@ -83,12 +94,14 @@ def save_yaml(
             yaml.indent(offset=2)
         else:
             yaml.default_flow_style = None
-        yaml.representer.add_representer(type(None), representer.represent_none)
-        yaml.dump(dictionary, f)
+        yaml.representer.add_representer(
+            type(None), representer.represent_none
+        )
+        yaml.dump(object, f)
 
 
 def save_json(
-    dictionary: Dict,
+    object: Any,
     path: str,
     encoding: str = "utf-8",
     pretty: bool = False,
@@ -97,7 +110,7 @@ def save_json(
     """Save dictionary to JSON file preserving order if it is an OrderedDict
 
     Args:
-        dictionary (Dict): Python dictionary to save
+        object (Any): Python object to save
         path (str): Path to JSON file
         encoding (str): Encoding of file. Defaults to utf-8.
         pretty (bool): Whether to pretty print. Defaults to False.
@@ -114,5 +127,9 @@ def save_json(
             indent = None
             separators = (", ", ": ")
         json.dump(
-            dictionary, f, indent=indent, sort_keys=sortkeys, separators=separators
+            object,
+            f,
+            indent=indent,
+            sort_keys=sortkeys,
+            separators=separators,
         )
